/* FAPI_F.H - FAPI User Functions and data structs
   Copyright (c) 1995 Sangoma Technologies Inc.
   Author: Glenn Robins
   API v0.1, 16-bit

   Application include file for FAPI.LIB functions.
   See FAPI.HLP for a complete function reference.

   Must #include <windows.h> before this header for type
   definitions used here.
*/

#define	MDATALEN	4096
#define	CB_HEADERLEN	15

/* FRIP control block */
typedef struct {
	char command;
	WORD buffer_length;
	char return_code;
	WORD dlci;
	char FECN_BECN_DE_CR_bits;
	WORD rx_frm_disc_int;
	DWORD rx_frm_disc_app;
	char reserved[2];
	char data[MDATALEN];
} CBLOCK;


/* FAPI will always return 1 */
int WINAPI FAPIAlive(void);

/* Initializes FAPI and loads SDLA driver, if not loaded already.
   A trace should be registered before this setup if one will
   be used at all, but is not necessary.
   Each application instance MUST call this on initialization.
   returns 0 if failed to load SDLA driver,
	   1 if this is the first setup call and the SDLA driver
	     loaded successfully,
	   2 if this is not the first successful setup call
	     (driver already loaded)
*/
int WINAPI FAPISetup(void);

/* Cleanup and unloads SDLA driver if this is the last
   application instance to use the driver.
   You must terminate your trace registration first if one
   was registered, unless you are the last application to use
   this DLL (but you shouldn't assume this).
   Each application instance MUST call this before closing.
   returns 1 always (return code reserved for future use)
*/
int WINAPI FAPICleanup(void);

/* Emulate FRIP interrupt call with control block
   returns return_code value in structure
*/
char WINAPI FAPIControl(CBLOCK far *block, BYTE cardnumber);

/* returns number of frames pending for read
*/
unsigned char WINAPI FAPInDataToRead(BYTE cardnumber);

/* returns 1 if clear to send bit is set, 0 if not
*/
char WINAPI FAPIqClearToXmit(BYTE cardnumber);


/* returns 0 if a debugging command trace is already registered or
   had difficulty creating the window, 1 if successful.
   hWnd is a window to send notification messages to, and
   iMessage is a user-defined message that FAPI will send the
   application to signal an FAPI notification. The actual
   message code is passed by value to the WPARAM parameter
   of the window procedure
*/
char WINAPI FAPIRegisterDebug(HINSTANCE hInstance, HWND hWnd, UINT iMessage);

/* if a debugging command trace is active and instance matches that passed
   when registered (for security/fault tolerance purposes) then
   trace is terminated and returns 0. If instance doesn't match,
   returns 1. If no trace is running, returns 2.
   The trace is also terminated automatically if the window is
   closed (see trace messages)
*/
char WINAPI FAPITerminateDebug(HINSTANCE hInstance);

/* returns TRUE if a debugging command trace is registered and active */
BOOL WINAPI FAPIIsDebugRegistered(void);

/* DEBUGGING COMMAND TRACE MESSAGES (wParam values) */
#define	TRACEMSG_CLOSE	0

/*
   returns SDLAR_NOT_REGISTERED (0L) if failed to obtain a selector
	(any read or write calls to the board will result
	in a general protection fault)
   returns SDLAR_REGISTERED if succeeded (1L): the card's
	instance count was incremented but this is not the
	first registration call for this board (it is already
	in use by an application)
   returns SDLAR_ALLOCATED if succeeded (2L): the card's
	instance count was incremented and this is the
	first registration call for this board, and the
	memory selector was allocated
*/
int WINAPI FAPIRegisterCard(BYTE cardnumber);

/*
   returns SDLAR_NOT_REGISTERED (0L) if card wasn't registered
   returns SDLAR_DEREGISTERED (1L) if card's instance count
	was decremented but isn't currently zero
	(i.e. an application is still using the specified board)
   returns SDLAR_RELEASED (2L) if card is now not used by
	any application, and the selector was freed
*/
int WINAPI FAPIDeregisterCard(BYTE cardnumber);

#define SDLAR_NOT_REGISTERED    0
#define SDLAR_DEREGISTERED      1
#define SDLAR_RELEASED          2
#define SDLAR_REGISTERED        1
#define SDLAR_ALLOCATED         2

/*
   returns a bit record (32-bit) of cards registered for use
	and cards that exist:
	[ E15 E14 ... E3 E2 E1 E0 R15 R14 ... R3 R2 R1 R0 ]
   For example, if bit R2 is set, then card 2 is registered
		if bit E2 is set, then card 2 exists
			(i.e. a configuration entry exists
                        in SDLA.INI)
*/
LRESULT WINAPI FAPIGetCards(void);

/* returns a byte indicating current modem status as follows:
	[ 0 0 CTS 0 DCD 0 0 0 ]
   CTS and DCD are high when these corresponding bits are set
*/
char WINAPI FAPIGetModemStatus(BYTE cardnumber);

/* Returns zero if no events to report, or the event code.
   The event code corresponds to the return codes 0x10 thru 0x14
   inclusive which would normally be returned on a FAPIControl
   call for any given command - therefore, once retrieved using this
   command, the event is cleared and will not be reported by a
   FAPIControl call in the future
   This is a very fast call, and should be used when polling for
   changes in channel status or DLCI status instead of using
   FAPIControl.  However, these sames codes may be obtained separately
   from a FAPIControl call and those same events will not be returned
   on a FAPIGetEvent call.

   The pertinent info is stored in cb if anything happens, otherwise
   it isn't used.
*/
char WINAPI FAPIGetEvent(CBLOCK far *cb, BYTE cardnumber);

/* returns events pending byte:
	[ 0 MODEM 0 0 0 UNCONF_DLCI DLCI_STAT CHAN_STAT ]
*/
char WINAPI FAPIGetEventsPending(BYTE cardnumber);


